@@ -4,8 +4,8 @@ import (
 	"encoding/json"
 	"path"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 const (
@@ -17,7 +17,7 @@ const (
 
 type Sitecore struct {
 	props properties.Properties
-	env   platform.Environment
+	env   runtime.Environment
 
 	EndpointName string
 	CmHost       string
@@ -62,7 +62,7 @@ func (s *Sitecore) Template() string {
 	return "{{ .EndpointName }} {{ if .CmHost }}({{ .CmHost }}){{ end }}"
 }
 
-func (s *Sitecore) Init(props properties.Properties, env platform.Environment) {
+func (s *Sitecore) Init(props properties.Properties, env runtime.Environment) {
 	s.props = props
 	s.env = env
 }
